@@ -15,7 +15,7 @@
 This module defines ZFiles global package interfaces.
 """
 
-from enum import Enum, IntEnum
+from enum import Enum
 
 from zope.container.constraints import containers, contains
 from zope.container.interfaces import IBTreeContainer
@@ -27,8 +27,7 @@ from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary
 from pyams_file.schema import FileField
 from pyams_security.interfaces import IContentRoles
 from pyams_security.schema import PrincipalField, PrincipalsSetField
-from pyams_workflow.interfaces import IWorkflow, IWorkflowManagedContent, \
-    IWorkflowPublicationSupport
+from pyams_workflow.interfaces import IWorkflow, IWorkflowManagedContent, IWorkflowPublicationSupport
 
 
 __docformat__ = 'restructuredtext'
@@ -40,14 +39,41 @@ from pyams_zfiles import _
 # API endpoints
 #
 
-REST_CONTAINER_ROUTE = 'zfiles.rest.container'
-REST_DOCUMENT_ROUTE = 'zfiles.rest.document'
-REST_SYNCHRONIZER_ROUTE = 'zfiles.rest.synchronizer'
+REST_CONTAINER_ROUTE = 'pyams_zfiles.rest.container'
+'''ZFiles container REST API route name'''
 
-GRAPHQL_API_ROUTE = 'zfiles.graphql'
+REST_CONTAINER_PATH = '/api/zfiles/rest'
+'''ZFiles container REST API default path'''
 
-JSONRPC_ENDPOINT = 'zfiles.jsonrpc'
-XMLRPC_ENDPOINT = 'zfiles.xmlrpc'
+REST_DOCUMENT_ROUTE = 'pyams_zfiles.rest.document'
+'''ZFiles document REST API route name'''
+
+REST_DOCUMENT_PATH = '/api/zfiles/rest/{oid}*version'
+'''ZFiles document REST API default path'''
+
+REST_SYNCHRONIZER_ROUTE = 'pyams_zfiles.rest.synchronizer'
+'''ZFiles synchronizer REST API route name'''
+
+REST_SYNCHRONIZER_PATH = '/api/zfiles/rest/synchronize'
+'''ZFiles synchronizer REST API default path'''
+
+GRAPHQL_API_ROUTE = 'pyams_zfiles.graphql'
+'''ZFiles GraphQL API route name'''
+
+GRAPHQL_API_PATH = '/api/zfiles/graphql'
+'''ZFiles GraphQL API default path'''
+
+JSONRPC_ENDPOINT = 'pyams_zfiles.jsonrpc'
+'''ZFiles JSON-RPC endpoint name'''
+
+JSONRPC_PATH = '/api/zfiles/jsonrpc'
+'''ZFiles JSON-RPC default path'''
+
+XMLRPC_ENDPOINT = 'pyams_zfiles.xmlrpc'
+'''ZFiles XML-RPC endpoint name'''
+
+XMLRPC_PATH = '/api/zfiles/xmlrpc'
+'''ZFiles XML-RPC default path'''
 
 
 #
@@ -55,11 +81,11 @@ XMLRPC_ENDPOINT = 'zfiles.xmlrpc'
 #
 
 PYAMS_ZFILES_SKIN_NAME = 'PyAMS.zfiles.skin'
-"""Custom ZFiles skin name"""
+'''Custom ZFiles skin name'''
 
 
 PYAMS_ZFILES_APPLICATIONS_VOCABULARY = 'PyAMS.zfiles.applications'
-"""Name of registered applications vocabulary"""
+'''Name of registered applications vocabulary'''
 
 
 #
@@ -118,45 +144,66 @@ class IDocumentWorkflow(IWorkflow):
     """Document workflow marker interface"""
 
 
-DRAFT_STATE = 'draft'
-PUBLISHED_STATE = 'published'
-ARCHIVED_STATE = 'archived'
-DELETED_STATE = 'deleted'
+class STATE(Enum):
+    """State modes"""
+    DRAFT = 'draft'
+    PUBLISHED = 'published'
+    ARCHIVED = 'archived'
+    DELETED = 'deleted'
+
+
+STATES_VALUES = tuple(map(lambda x: x.value, STATE))
+
 
 STATE_LABELS = {
-    DRAFT_STATE: _("Draft"),
-    PUBLISHED_STATE: _("Published"),
-    ARCHIVED_STATE: _("Archived"),
-    DELETED_STATE: _("Deleted")
+    STATE.DRAFT.value: _("Draft"),
+    STATE.PUBLISHED.value: _("Published"),
+    STATE.ARCHIVED.value: _("Archived"),
+    STATE.DELETED.value: _("Deleted")
+}
+
+STATES_HEADERS = {
+    STATE.DRAFT.value: _("draft created"),
+    STATE.PUBLISHED.value: _("published"),
+    STATE.ARCHIVED.value: _("archived")
+}
+
+STATES_VOCABULARY = SimpleVocabulary([
+    SimpleTerm(i, title=t)
+    for i, t in STATE_LABELS.items()
+])
+
+
+class ACCESS_MODE(Enum):
+    """Security policy access modes"""
+    PRIVATE = 'private'
+    PROTECTED = 'protected'
+    PUBLIC = 'public'
+
+    @classmethod
+    def _missing_(cls, value):
+        if isinstance(value, int):
+            try:
+                return list(ACCESS_MODE)[value]
+            except IndexError:
+                pass
+        raise ValueError("%r is not a valid %s" % (value, cls.__name__))
+
+
+# Keep for compatibility reason
+AccessMode = ACCESS_MODE
+
+
+ACCESS_MODE_LABELS = {
+    ACCESS_MODE.PRIVATE.value: _("Private"),
+    ACCESS_MODE.PROTECTED.value: _("Protected"),
+    ACCESS_MODE.PUBLIC.value: _("Public")
 }
 
 
-class AccessMode(IntEnum):
-    """Access modes"""
-    private = 0  # pylint: disable=invalid-name
-    protected = 1  # pylint: disable=invalid-name
-    public = 2  # pylint: disable=invalid-name
-
-
-PRIVATE_MODE = AccessMode.private
-PROTECTED_MODE = AccessMode.protected
-PUBLIC_MODE = AccessMode.public
-
-ACCESS_MODE_IDS = [
-    'private',
-    'protected',
-    'public'
-]
-
-ACCESS_MODE_LABELS = (
-    _("Private"),
-    _("Protected"),
-    _("Public")
-)
-
-
 ACCESS_MODE_VOCABULARY = SimpleVocabulary([
-    SimpleTerm(i, t, t) for i, t in enumerate(ACCESS_MODE_LABELS)
+    SimpleTerm(i, title=t)
+    for i, t in ACCESS_MODE_LABELS.items()
 ])
 
 
@@ -202,13 +249,13 @@ class IDocumentVersion(IWorkflowPublicationSupport):
                          description=_("Access mode on this document"),
                          required=True,
                          vocabulary=ACCESS_MODE_VOCABULARY,
-                         default=PRIVATE_MODE)
+                         default=ACCESS_MODE.PRIVATE.value)
 
     update_mode = Choice(title=_("Update mode"),
                          description=_("Update mode on this document"),
                          required=True,
                          vocabulary=ACCESS_MODE_VOCABULARY,
-                         default=PRIVATE_MODE)
+                         default=ACCESS_MODE.PRIVATE.value)
 
     properties = PropertiesField(title=_("Properties"),
                                  description=_("List of free additional properties which can be "
